/********************************************************************************
 * Copyright (c) 2023 CEA-List
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 ********************************************************************************/

#include <cstddef>
#include <cstdint>
#include <string>
#include <vector>

#include "aidge/operator/Gather.hpp"
#include "aidge/utils/ErrorHandling.hpp"
#include "aidge/utils/Types.h"

const std::string Aidge::Gather_Op::Type = "Gather";

void Aidge::Gather_Op::computeOutputDims() {
    // check inputs have been associated
    if (!getInput(0) || !getInput(1)) {
        AIDGE_THROW_OR_ABORT(std::runtime_error, "At least one input was not connected");
    }

    if (!getInput(0)->empty() && !getInput(1)->empty()) {
        std::vector<DimSize_t> outDims = getInput(0)->dims();
        std::vector<DimSize_t> indicesDims = getInput(1)->dims();

        std::int64_t axisIdx = this->template getAttr<GatherAttr::Axis>()>=0?
                               this->template getAttr<GatherAttr::Axis>():
                               this->template getAttr<GatherAttr::Axis>()+outDims.size();
        outDims.erase(outDims.begin() + static_cast<std::size_t>(axisIdx));
        if( indicesDims[0]>0 ) // In case indices is a scalar indicesDims is a 0 
        {
            outDims.insert(outDims.begin() + static_cast<std::size_t>(axisIdx), indicesDims.begin(),indicesDims.end());
        }
        mOutputs[0]->resize(outDims);
    }
}